@@ -3,7 +3,7 @@ package App::ZofCMS::Plugin::BoolSettingsManager;
 use warnings;
 use strict;
 
-our $VERSION = '1.001002'; # VERSION
+our $VERSION = '1.001003'; # VERSION
 
 use base 'App::ZofCMS::Plugin::Base';
 use HTML::Template;
@@ -212,7 +212,7 @@ The module is a plugin for L<App::ZofCMS> that provides means to present
 a user a form with a number of checkboxes that control boolean settings,
 which are stored in a SQL database.
 
-This documeantation assumes you've read L<App::ZofCMS>,
+This documentation assumes you've read L<App::ZofCMS>,
 L<App::ZofCMS::Config> and L<App::ZofCMS::Template>.
 
 =head1 FIRST-LEVEL ZofCMS TEMPLATE AND MAIN CONFIG FILE KEYS
@@ -283,7 +283,7 @@ If C<settings> is not specified, or its arrayref is empty, or if the subref
 returns C<undef>, empty arrayref or empty list, plugin will stop further
 execution.
 
-The arrayref must have an even number of elemeants that are to be thought
+The arrayref must have an even number of elements that are to be thought
 of as keys and values (the arrayref is used to preserve order). The "keys"
 of the arrayref represent boolean column names in C<table> (see below)
 SQL table in which users' settings are stored (one setting per column).
@@ -303,7 +303,7 @@ of their corresponding "keys". These will be shown as text in the C<<
 
 B<Optional, but the default is pretty useless>.
 The C<dsn> key will be passed to L<DBI>'s
-C<connect_cached()> method, see documeantation for L<DBI> and
+C<connect_cached()> method, see documentation for L<DBI> and
 C<DBD::your_database> for the correct syntax for this one.
 The example above uses MySQL database called C<test> which is
 located on C<localhost>.
@@ -391,7 +391,7 @@ C<< sub { $_[0]->{d}{user}{login} } >>
 
 B<Optional>. Takes HTML code as a value, which represents the submit
 button to be used on the settings-changing form. Feel free to throw in
-any extra code into this argumeant. B<Defaults to:>
+any extra code into this argument. B<Defaults to:>
 C<< <input type="submit" class="input_submit" value="Save"> >>
 
 =head1 HTML::Template TEMPLATE VARIABLE
@@ -404,7 +404,7 @@ L<HTML::Template> template:
 =head1 HTML CODE GENERATED BY THE PLUGIN
 
 The HTML code below was generated after saving settings in the form
-generated using this plugin's C<settings> argumeant:
+generated using this plugin's C<settings> argument:
 
     settings => [
         notice_forum         => q|new forum posts|,
@@ -413,7 +413,7 @@ generated using this plugin's C<settings> argumeant:
     ],
 
 Notice the "keys" in the C<settings> arrayref are used to generate
-C<id=""> attributes on the C<< <li> >> and C<< <input> >> elemeants
+C<id=""> attributes on the C<< <li> >> and C<< <input> >> elements
 (and C<for=""> attribute on C<< <label> >>s). The value for C<page>
 hidden C<< <input> >> is derived by the plugin automagically.
 
